@@ -1,10 +1,16 @@
 base=/usr/ports/lang/cacao
 wrksrc=w-cacao-0.95/cacao-0.95
-(cd $base/$wrksrc; find src | grep "$2"  > /tmp/match)
+test x"$1" = x -o x"$2" = x && echo usage && exit 0
+(cd $base/$wrksrc; find src | grep "$2" | grep -v '\.orig$'  > /tmp/match)
 if eval test "`wc -l </tmp/match`" -gt 1; then
-	echo "[ambiguous]" 1>&2
-	cat /tmp/match
-	exit
+	# if the named one exists then it wins
+	if grep "$2\$" /tmp/match >/tmp/match1; then
+		cp /tmp/match1 /tmp/match
+	else
+		echo "[ambiguous]" 1>&2
+		cat /tmp/match
+		exit
+	fi
 fi
 if eval test "`wc -l </tmp/match`" -eq 0; then
 	echo "[not found]" 1>&2
@@ -43,6 +49,10 @@ case "$1" in
 		;;
 
 	* )
-		echo usage
+		if test -x "$1"; then
+			eval $1 $base/w-cacao-0.95/cacao-0.95/$file $base/files/tmp/cacao-0.95/$file
+		else
+			echo usage
+		fi
 		;;
 esac
